django_celery_results.backends.database — django_celery_results 1.0.0 documentation

# `django_celery_results.backends.database`

class `django_celery_results.backends.database.` `DatabaseBackend`(app, serializer=None, max_cached_results=None, accept=None, expires=None, expires_type=None, url=None, **kwargs)

  The Django database backend, using models to store task state.

  `TaskModel`

    alias of `TaskResult`

  `cleanup`()

    Delete expired metadata.

  `decode_content`(obj, content)
  `encode_content`(data)
  `subpolling_interval` = 0.5